==> mpich_1.2.5.2.orig.tar.gz: mpich-1.2.5.2/mpid/nt_server/winmpd/MPIConfig/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by MPIConfig.rc
//
#define IDD_MPICONFIG_DIALOG            102
#define IDR_MAINFRAME                   128
#define IDD_SET_DIALOG                  129
#define IDD_PHRASE_DLG                  131
#define IDB_RED_BITMAP                  133
#define IDB_YELLOW_BITMAP               134
#define IDB_GREEN_BITMAP                135
#define IDD_FIND_HOSTS_DLG              136
#define IDR_FIND_MENU                   137
#define IDD_CONFIG_DLG                  137
#define IDD_DOMAIN_DLG                  138
#define IDI_ICON_NO                     138
#define IDD_CONNECTION_OPTIONS_DLG      139
#define IDI_ICON_YES                    139
#define IDD_WILDCARD_DLG                140
#define IDC_FIND_BTN                    1000
#define IDC_VERIFY_BTN                  1001
#define IDC_SET_BTN                     1002
#define IDC_LIST                        1003
#define IDC_REFRESH_BTN                 1004
#define IDC_SET_ONE_BTN                 1005
#define IDC_HOSTS_CHK                   1007
#define IDC_TEMP_CHK                    1008
#define IDC_TEMP_EDIT                   1009
#define IDC_TIMEOUT_CHK                 1010
#define IDC_LAUNCH_TIMEOUT              1011
#define IDC_HOST_LIST                   1013
#define IDC_HOSTNAME                    1014
#define IDC_ADD_BTN                     1015
#define IDC_EDIT_ADD_BTN                1016
#define IDC_PASSWORD                    1017
#define IDC_PHRASE_RADIO                1018
#define IDC_DEFAULT_RADIO               1019
#define IDC_DOMAIN                      1020
#define IDC_STATIC_EDIT                 1021
#define IDC_ONE_STATIC                  1023
#define IDC_TWO_STATIC                  1024
#define IDC_THREE_STATIC                1025
#define IDC_TEMP_STATIC                 1026
#define IDC_PWD_STATIC                  1027
#define IDC_APPLY_STATIC                1028
#define IDC_PHRASE_STATIC               1029
#define IDC_STOPLIGHT_RED               1030
#define IDC_STOPLIGHT_GREEN             1031
#define IDC_STOPLIGHT_YELLOW            1032
#define IDC_SHOW_HOST_CHK               1033
#define IDC_HOST_CONFIG                 1034
#define IDC_APPLY_ONE_STATIC            1035
#define IDC_SELECT_BTN                  1036
#define IDC_ADD_HOSTNAME                1037
#define IDC_SHOW_CONFIG_CHK             1038
#define IDC_LAUNCH_CHK                  1040
#define IDC_USE_JOBHOST_CHK             1041
#define IDC_JOBHOST_EDIT                1042
#define IDC_USE_JOBHOST_PWD_CHK         1043
#define IDC_JOBHOST_PWD_EDIT            1044
#define IDC_COLOR_CHK                   1045
#define IDC_DOTS_CHK                    1046
#define IDC_MAPPING_CHK                 1047
#define IDC_POPUP_DEBUG_CHK             1048
#define IDC_HOSTS_EDIT                  1049
#define IDC_DOMAIN_HOST_LIST            1050
#define IDC_LAUNCH_EDIT                 1050
#define IDC_ENCODED_HOSTS               1051
#define IDC_CATCH_CHK                   1051
#define IDC_HOST_HOSTS_CHK              1052
#define IDC_DOMAIN_EDIT                 1053
#define IDC_HOST_LAUNCH_CHK             1053
#define IDC_HOST_USE_JOBHOST_CHK        1054
#define IDC_HOST_JOBHOST_EDIT           1055
#define IDC_PASSPHRASE                  1056
#define IDC_HOST_USE_JOBHOST_PWD_CHK    1056
#define IDC_DEFAULT_PASSPHRASE_RADIO    1057
#define IDC_HOST_JOBHOST_PWD_EDIT       1057
#define IDC_PORT                        1058
#define IDC_HOST_COLOR_CHK              1058
#define IDC_DEFAULT_PORT_RADIO          1059
#define IDC_HOST_DOTS_CHK               1059
#define IDC_PASSPHRASE_RADIO            1060
#define IDC_HOST_MAPPING_CHK            1060
#define IDC_PORT_RADIO                  1061
#define IDC_HOST_POPUP_DEBUG_CHK        1061
#define IDC_FAST_CHECK                  1062
#define IDC_HOST_HOSTS_EDIT             1062
#define IDC_HOST_LAUNCH_EDIT            1063
#define IDC_HOST_JOBHOST_YES            1064
#define IDC_HOST_JOBHOST_NO             1065
#define IDC_HOST_COLOR_YES              1066
#define IDC_HOST_COLOR_NO               1067
#define IDC_HOST_DOTS_YES               1068
#define IDC_HOST_DOTS_NO                1069
#define IDC_HOST_MAPPING_YES            1070
#define IDC_HOST_MAPPING_NO             1071
#define IDC_HOST_POPUP_DEBUG_YES        1072
#define IDC_HOST_POPUP_DEBUG_NO         1073
#define IDC_HOST_STATIC                 1074
#define IDC_APPLY_BTN                   1075
#define IDC_APPLY_SINGLE_BTN            1076
#define IDC_MODIFY_BTN                  1077
#define IDC_PROGRESS                    1078
#define IDC_DOTS_YES                    1079
#define IDC_DOTS_NO                     1080
#define IDC_COLOR_YES                   1081
#define IDC_COLOR_NO                    1082
#define IDC_MAPPING_YES                 1083
#define IDC_MAPPING_NO                  1084
#define IDC_POPUP_DEBUG_YES             1085
#define IDC_POPUP_DEBUG_NO              1086
#define IDC_JOBHOST_YES                 1087
#define IDC_JOBHOST_NO                  1088
#define IDC_HOST_TOGGLE_BTN             1089
#define IDC_TOGGLE_BTN                  1090
#define IDC_MPD_PWD_STATIC              1091
#define IDC_MPD_PHRASE_RADIO            1092
#define IDC_MPD_PHRASE                  1093
#define IDC_MPD_PHRASE_DEFAULT_RADIO    1094
#define IDC_PHRASE_BOX_STATIC           1095
#define IDC_JOBHOST_STATIC              1096
#define IDC_APPLY_SINGLE_STATIC         1097
#define IDC_MODIFY_STATIC               1098
#define IDC_N_OF_M_STATIC               1099
#define IDC_CODES_CHK                   1100
#define IDC_CATCH_YES                   1101
#define IDC_CATCH_NO                    1102
#define IDC_HOST_CATCH_CHK              1103
#define IDC_HOST_CATCH_YES              1104
#define IDC_HOST_CATCH_NO               1105
#define IDC_HOST_MSG_STATIC             1106
#define IDC_CODES_YES                   1107
#define IDC_WILDSTR_EDIT                1107
#define IDC_CODES_NO                    1108
#define IDC_HOST_CODES_CHK              1109
#define IDC_HOST_CODES_YES              1110
#define IDC_HOST_CODES_NO               1111
#define IDC_REDIRECT_MPD_CHK            1112
#define IDC_REDIRECT_MPD_YES            1113
#define IDC_REDIRECT_MPD_NO             1114
#define IDC_REDIRECT_MPD_STATIC         1115
#define IDC_REDIRECT_MPD_EDIT           1116
#define IDC_HOST_REDIRECT_MPD_CHK       1117
#define IDC_HOST_REDIRECT_MPD_YES       1118
#define IDC_HOST_REDIRECT_MPD_NO        1119
#define IDC_HOST_REDIRECT_MPD_EDIT      1120
#define ID_FILE_FINDHOSTS               32771
#define ID_FILE_LOADLIST                32772
#define ID_FILE_SAVELIST                32773
#define ID_FILE_EXIT                    32774
#define ID_FILE_CHANGEDOMAIN            32775
#define ID_FILE_VERIFY                  32776
#define ID_FILE_CONNECTIONOPTIONS       32777
#define ID_ACTION_WILDCARDSCANHOSTS     32778

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        141
#define _APS_NEXT_COMMAND_VALUE         32779
#define _APS_NEXT_CONTROL_VALUE         1108
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> mpich_1.2.5.3.orig.tar.gz: mpich-1.2.5.3/mpid/nt_server/winmpd/MPIConfig/resource.h <==
/* -*- Mode: C; c-basic-offset:4 ; -*- */
/*
 *  (C) 2001 by Argonne National Laboratory.
 *      See COPYRIGHT in top-level directory.
 */
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by MPIConfig.rc
//
#define IDD_MPICONFIG_DIALOG            102
#define IDR_MAINFRAME                   128
#define IDD_SET_DIALOG                  129
#define IDD_PHRASE_DLG                  131
#define IDB_RED_BITMAP                  133
#define IDB_YELLOW_BITMAP               134
#define IDB_GREEN_BITMAP                135
#define IDD_FIND_HOSTS_DLG              136
#define IDR_FIND_MENU                   137
#define IDD_CONFIG_DLG                  137
#define IDD_DOMAIN_DLG                  138
#define IDI_ICON_NO                     138
#define IDD_CONNECTION_OPTIONS_DLG      139
#define IDI_ICON_YES                    139
#define IDD_WILDCARD_DLG                140
#define IDC_FIND_BTN                    1000
#define IDC_VERIFY_BTN                  1001
#define IDC_SET_BTN                     1002
#define IDC_LIST                        1003
#define IDC_REFRESH_BTN                 1004
#define IDC_SET_ONE_BTN                 1005
#define IDC_HOSTS_CHK                   1007
#define IDC_TEMP_CHK                    1008
#define IDC_TEMP_EDIT                   1009
#define IDC_TIMEOUT_CHK                 1010
#define IDC_LAUNCH_TIMEOUT              1011
#define IDC_HOST_LIST                   1013
#define IDC_HOSTNAME                    1014
#define IDC_ADD_BTN                     1015
#define IDC_EDIT_ADD_BTN                1016
#define IDC_PASSWORD                    1017
#define IDC_PHRASE_RADIO                1018
#define IDC_DEFAULT_RADIO               1019
#define IDC_DOMAIN                      1020
#define IDC_STATIC_EDIT                 1021
#define IDC_ONE_STATIC                  1023
#define IDC_TWO_STATIC                  1024
#define IDC_THREE_STATIC                1025
#define IDC_TEMP_STATIC                 1026
#define IDC_PWD_STATIC                  1027
#define IDC_APPLY_STATIC                1028
#define IDC_PHRASE_STATIC               1029
#define IDC_STOPLIGHT_RED               1030
#define IDC_STOPLIGHT_GREEN             1031
#define IDC_STOPLIGHT_YELLOW            1032
#define IDC_SHOW_HOST_CHK               1033
#define IDC_HOST_CONFIG                 1034
#define IDC_APPLY_ONE_STATIC            1035
#define IDC_SELECT_BTN                  1036
#define IDC_ADD_HOSTNAME                1037
#define IDC_SHOW_CONFIG_CHK             1038
#define IDC_LAUNCH_CHK                  1040
#define IDC_USE_JOBHOST_CHK             1041
#define IDC_JOBHOST_EDIT                1042
#define IDC_USE_JOBHOST_PWD_CHK         1043
#define IDC_JOBHOST_PWD_EDIT            1044
#define IDC_COLOR_CHK                   1045
#define IDC_DOTS_CHK                    1046
#define IDC_MAPPING_CHK                 1047
#define IDC_POPUP_DEBUG_CHK             1048
#define IDC_HOSTS_EDIT                  1049
#define IDC_DOMAIN_HOST_LIST            1050
#define IDC_LAUNCH_EDIT                 1050
#define IDC_ENCODED_HOSTS               1051
#define IDC_CATCH_CHK                   1051
#define IDC_HOST_HOSTS_CHK              1052
#define IDC_DOMAIN_EDIT                 1053
#define IDC_HOST_LAUNCH_CHK             1053
#define IDC_HOST_USE_JOBHOST_CHK        1054
#define IDC_HOST_JOBHOST_EDIT           1055
#define IDC_PASSPHRASE                  1056
#define IDC_HOST_USE_JOBHOST_PWD_CHK    1056
#define IDC_DEFAULT_PASSPHRASE_RADIO    1057
#define IDC_HOST_JOBHOST_PWD_EDIT       1057
#define IDC_PORT                        1058
#define IDC_HOST_COLOR_CHK              1058
#define IDC_DEFAULT_PORT_RADIO          1059
#define IDC_HOST_DOTS_CHK               1059
#define IDC_PASSPHRASE_RADIO            1060
#define IDC_HOST_MAPPING_CHK            1060
#define IDC_PORT_RADIO                  1061
#define IDC_HOST_POPUP_DEBUG_CHK        1061
#define IDC_FAST_CHECK                  1062
#define IDC_HOST_HOSTS_EDIT             1062
#define IDC_HOST_LAUNCH_EDIT            1063
#define IDC_HOST_JOBHOST_YES            1064
#define IDC_HOST_JOBHOST_NO             1065
#define IDC_HOST_COLOR_YES              1066
#define IDC_HOST_COLOR_NO               1067
#define IDC_HOST_DOTS_YES               1068
#define IDC_HOST_DOTS_NO                1069
#define IDC_HOST_MAPPING_YES            1070
#define IDC_HOST_MAPPING_NO             1071
#define IDC_HOST_POPUP_DEBUG_YES        1072
#define IDC_HOST_POPUP_DEBUG_NO         1073
#define IDC_HOST_STATIC                 1074
#define IDC_APPLY_BTN                   1075
#define IDC_APPLY_SINGLE_BTN            1076
#define IDC_MODIFY_BTN                  1077
#define IDC_PROGRESS                    1078
#define IDC_DOTS_YES                    1079
#define IDC_DOTS_NO                     1080
#define IDC_COLOR_YES                   1081
#define IDC_COLOR_NO                    1082
#define IDC_MAPPING_YES                 1083
#define IDC_MAPPING_NO                  1084
#define IDC_POPUP_DEBUG_YES             1085
#define IDC_POPUP_DEBUG_NO              1086
#define IDC_JOBHOST_YES                 1087
#define IDC_JOBHOST_NO                  1088
#define IDC_HOST_TOGGLE_BTN             1089
#define IDC_TOGGLE_BTN                  1090
#define IDC_MPD_PWD_STATIC              1091
#define IDC_MPD_PHRASE_RADIO            1092
#define IDC_MPD_PHRASE                  1093
#define IDC_MPD_PHRASE_DEFAULT_RADIO    1094
#define IDC_PHRASE_BOX_STATIC           1095
#define IDC_JOBHOST_STATIC              1096
#define IDC_APPLY_SINGLE_STATIC         1097
#define IDC_MODIFY_STATIC               1098
#define IDC_N_OF_M_STATIC               1099
#define IDC_CODES_CHK                   1100
#define IDC_CATCH_YES                   1101
#define IDC_CATCH_NO                    1102
#define IDC_HOST_CATCH_CHK              1103
#define IDC_HOST_CATCH_YES              1104
#define IDC_HOST_CATCH_NO               1105
#define IDC_HOST_MSG_STATIC             1106
#define IDC_CODES_YES                   1107
#define IDC_WILDSTR_EDIT                1107
#define IDC_CODES_NO                    1108
#define IDC_HOST_CODES_CHK              1109
#define IDC_HOST_CODES_YES              1110
#define IDC_HOST_CODES_NO               1111
#define IDC_REDIRECT_MPD_CHK            1112
#define IDC_REDIRECT_MPD_YES            1113
#define IDC_REDIRECT_MPD_NO             1114
#define IDC_REDIRECT_MPD_STATIC         1115
#define IDC_REDIRECT_MPD_EDIT           1116
#define IDC_HOST_REDIRECT_MPD_CHK       1117
#define IDC_HOST_REDIRECT_MPD_YES       1118
#define IDC_HOST_REDIRECT_MPD_NO        1119
#define IDC_HOST_REDIRECT_MPD_EDIT      1120
#define IDC_LOCALROOT_CHK               1121
#define IDC_LOCALROOT_YES               1122
#define IDC_LOCALROOT_NO                1123
#define IDC_HOST_LOCALROOT_CHK          1124
#define IDC_HOST_LOCALROOT_YES          1125
#define IDC_HOST_LOCALROOT_NO           1126
#define ID_FILE_FINDHOSTS               32771
#define ID_FILE_LOADLIST                32772
#define ID_FILE_SAVELIST                32773
#define ID_FILE_EXIT                    32774
#define ID_FILE_CHANGEDOMAIN            32775
#define ID_FILE_VERIFY                  32776
#define ID_FILE_CONNECTIONOPTIONS       32777
#define ID_ACTION_WILDCARDSCANHOSTS     32778

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        141
#define _APS_NEXT_COMMAND_VALUE         32779
#define _APS_NEXT_CONTROL_VALUE         1108
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
